﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Threading.Tasks;

namespace NugetRestClient
{
    class Program
    {
        public static async Task<int> Main(string[] args)
        {
            string apiKey = File.ReadAllText(@"nuget.key.txt");
            NugetClient client = new NugetClient(apiKey);

            string packageId = "TestPackage";

            if (args.Length >= 1)
            {
                packageId = args[0];
            }

            await client.GetFeedAsync();

            // (기본값 20개를 반환)
            // 페이징 처리를 위해 skip={SKIP}&take={TAKE} 인자 추가하면서 120개 까지의 목록을 반환
            foreach (PackageInfo result in await client.GetAllPackageListAsync(120))
            {
                Console.WriteLine(result.id);
            }

            PackageInfo itemInfo = await client.GetPackageInfoAsync(packageId, true);
            if (itemInfo == null)
            {
                Console.WriteLine($"{packageId}: NOT FOUND");
                return 1;
            }

            Console.WriteLine(itemInfo.description);
            for (int i = 0; i < itemInfo.versions.Count; i ++)
            {
                Console.WriteLine(itemInfo.versions[i].version);
                Console.WriteLine(itemInfo.versions[i].id);
            }

            string versionPrefix = "1.0.0.0";
            string checkPostfix = versionPrefix + "-alpha";
            int alphaNumber = 1;

            while (true)
            {
                PackageMetadata item = await client.GetPackageMetadataAsync(packageId, checkPostfix);
                if (item == null)
                {
                    break;
                }

                if (item.listed == true)
                {
                    await client.UnlistVersionPackageAsync(packageId, checkPostfix);
                }

                alphaNumber++;
                checkPostfix = $"{versionPrefix}-alpha{alphaNumber}";
            }

            Console.WriteLine("Next candidate version: " + checkPostfix);

            return 0;
        }
    }
}
